###############################################################################################################################################
#                    R Script for the pre-analysis of Fournier-Level et al. 2013, submitted to Molecular Ecology                              #
#                       - This script needs to be run before the SEM_models.r can be run (within the same R session)                          #
#                       - Inform the working directory below first comment and the planting site you are interested in below the second one   #
#                       - 2 libraries are required to run the model R\FactoMineR and R\sem, make sure you download them first                 #
#                       - Enter the datafile Fournier-leveletal_SEM_Data.txt in the pop-up window                                             #
#                       - for help e-mail: afournier@unimelb.edu.au                                                                           #
###############################################################################################################################################

#You have to provide the working directory were the Fournier-Leveletal_SEM_Data.txt file is located
MyPath="C:/"

#You have to provide the location you want to analyze (either "H" for Halle GER, "K" for Cologne GER,
PlantingSite="V"

library(sem)
library(FactoMineR)
setwd(MyPath)

Sem.File<-file.choose()

Data<-read.table(Sem.File,na.string="NA",header=T,dec=".",sep="\t")

#To subset over a reduced Loc
Sem.Data<-subset(Data,Data$Loc==PlantingSite)

n.Sem.Data<-nrow(Sem.Data)

Loc<-as.numeric(Sem.Data$Loc)
Fam<-as.numeric(Sem.Data$Family)
MPTUtB<-as.numeric(Sem.Data$MPTUtB)
MPTUtF<-as.numeric(Sem.Data$MPTUtF)
LfL<-as.numeric(Sem.Data$LfL)
Branch<-as.numeric(Sem.Data$Branch)
SIL_num<-as.numeric(Sem.Data$SIL_num)

TestMPTUtB<-lm(MPTUtB~Fam)
TestMPTUtF<-lm(MPTUtF~Fam)
TestLfL<-lm(LfL~Fam)
TestBranch<-lm(Branch~Fam)
TestSIL_num<-lm(SIL_num~Fam)

Sem.Data.res<-as.matrix(cbind(as.vector(TestMPTUtB$residuals),as.vector(TestMPTUtF$residuals),as.vector(TestLfL$residuals),as.vector(TestBranch$residuals),as.vector(TestSIL_num$residuals)))


#preparing the phenotypic data
MPTUtB<-as.numeric(Sem.Data.res[,1])
MPTUtF<-as.numeric(Sem.Data.res[,2])
LfL<-as.numeric(Sem.Data.res[,3])
Branch<-as.numeric(Sem.Data.res[,4])
SIL_num<-as.numeric(Sem.Data.res[,5])

#preparing the QTL data
QTL1.04_MPTUtBinH=as.numeric(Sem.Data$QTL1.04_MPTUtBinH)
QTL1.05_MPTUtFinH=as.numeric(Sem.Data$QTL1.05_MPTUtFinH)
QTL2.48_MPTUtBinH=as.numeric(Sem.Data$QTL2.48_MPTUtBinH)
QTL2.52_MPTUtFinH=as.numeric(Sem.Data$QTL2.52_MPTUtFinH)
QTL3.35_SIL_numinH=as.numeric(Sem.Data$QTL3.35_SIL_numinH)
QTL3.44_BranchinH=as.numeric(Sem.Data$QTL3.44_BranchinH)
QTL4.03_LfLinH=as.numeric(Sem.Data$QTL4.03_LfLinH)
QTL4.05_MPTUtFinH=as.numeric(Sem.Data$QTL4.05_MPTUtFinH)
QTL4.07_MPTUtBinH=as.numeric(Sem.Data$QTL4.07_MPTUtBinH)
QTL4.28_LfLinH=as.numeric(Sem.Data$QTL4.28_LfLinH)
QTL4.43_MPTUtBinH=as.numeric(Sem.Data$QTL4.43_MPTUtBinH)
QTL4.43_MPTUtFinH=as.numeric(Sem.Data$QTL4.43_MPTUtFinH)
QTL4.54_SIL_numinH=as.numeric(Sem.Data$QTL4.54_SIL_numinH)
QTL5.26_MPTUtFinH=as.numeric(Sem.Data$QTL5.26_MPTUtFinH)
QTL5.82_LfLinH=as.numeric(Sem.Data$QTL5.82_LfLinH)
QTL5.92_MPTUtBinH=as.numeric(Sem.Data$QTL5.92_MPTUtBinH)
QTL1.04_MPTUtBinK=as.numeric(Sem.Data$QTL1.04_MPTUtBinK)
QTL1.04_MPTUtFinK=as.numeric(Sem.Data$QTL1.04_MPTUtFinK)
QTL1.13_MPTUtBinK=as.numeric(Sem.Data$QTL1.13_MPTUtBinK)
QTL2.03_BranchinK=as.numeric(Sem.Data$QTL2.03_BranchinK)
QTL2.03_SIL_numinK=as.numeric(Sem.Data$QTL2.03_SIL_numinK)
QTL2.22_MPTUtFinK=as.numeric(Sem.Data$QTL2.22_MPTUtFinK)
QTL3.80_MPTUtFinK=as.numeric(Sem.Data$QTL3.80_MPTUtFinK)
QTL4.04_MPTUtBinK=as.numeric(Sem.Data$QTL4.04_MPTUtBinK)
QTL4.39_LfLinK=as.numeric(Sem.Data$QTL4.39_LfLinK)
QTL5.27_MPTUtBinK=as.numeric(Sem.Data$QTL5.27_MPTUtBinK)
QTL5.92_MPTUtFinK=as.numeric(Sem.Data$QTL5.92_MPTUtFinK)
QTL5.95_MPTUtBinK=as.numeric(Sem.Data$QTL5.95_MPTUtBinK)
QTL1.04_SIL_numinN=as.numeric(Sem.Data$QTL1.04_SIL_numinN)
QTL1.15_MPTUtBinN=as.numeric(Sem.Data$QTL1.15_MPTUtBinN)
QTL1.84_MPTUtFinN=as.numeric(Sem.Data$QTL1.84_MPTUtFinN)
QTL2.26_SIL_numinN=as.numeric(Sem.Data$QTL2.26_SIL_numinN)
QTL4.01_MPTUtBinN=as.numeric(Sem.Data$QTL4.01_MPTUtBinN)
QTL4.01_MPTUtFinN=as.numeric(Sem.Data$QTL4.01_MPTUtFinN)
QTL4.73_LfLinK=as.numeric(Sem.Data$QTL4.73_LfLinK)
QTL5.24_MPTUtBinN=as.numeric(Sem.Data$QTL5.24_MPTUtBinN)
QTL5.25_BranchinN=as.numeric(Sem.Data$QTL5.25_BranchinN)
QTL5.25_MPTUtFinN=as.numeric(Sem.Data$QTL5.25_MPTUtFinN)
QTL5.26_SIL_numinN=as.numeric(Sem.Data$QTL5.26_SIL_numinN)
QTL5.32_LfLinN=as.numeric(Sem.Data$QTL5.32_LfLinN)
QTL5.92_BranchinN=as.numeric(Sem.Data$QTL5.92_BranchinN)
QTL2.02_MPTUtBinV=as.numeric(Sem.Data$QTL2.02_MPTUtBinV)
QTL2.18_MPTUtFinV=as.numeric(Sem.Data$QTL2.18_MPTUtFinV)
QTL3.39_LfLinV=as.numeric(Sem.Data$QTL3.39_LfLinV)
QTL5.06_LfLinV=as.numeric(Sem.Data$QTL5.06_LfLinV)
QTL5.06_MPTUtBinV=as.numeric(Sem.Data$QTL5.06_MPTUtBinV)
QTL5.90_LfLinV=as.numeric(Sem.Data$QTL5.90_LfLinV)
QTL5.90_MPTUtFinV=as.numeric(Sem.Data$QTL5.90_MPTUtFinV)
QTL5.95_MPTUtBinV=as.numeric(Sem.Data$QTL5.95_MPTUtBinV)

#preparing the covariance matrix
Data=cbind(MPTUtB,LfL,MPTUtF,Branch,SIL_num,QTL1.04_MPTUtBinH,QTL1.05_MPTUtFinH,QTL2.48_MPTUtBinH,QTL2.52_MPTUtFinH,QTL3.35_SIL_numinH,QTL3.44_BranchinH,QTL4.03_LfLinH,QTL4.05_MPTUtFinH,QTL4.07_MPTUtBinH,QTL4.28_LfLinH,QTL4.43_MPTUtBinH,QTL4.43_MPTUtFinH,QTL4.54_SIL_numinH,QTL5.26_MPTUtFinH,QTL5.82_LfLinH,QTL5.92_MPTUtBinH,QTL1.04_MPTUtBinK,QTL1.04_MPTUtFinK,QTL1.13_MPTUtBinK,QTL2.03_BranchinK,QTL2.03_SIL_numinK,QTL2.22_MPTUtFinK,QTL3.80_MPTUtFinK,QTL4.04_MPTUtBinK,QTL4.39_LfLinK,QTL5.27_MPTUtBinK,QTL5.92_MPTUtFinK,QTL5.95_MPTUtBinK,QTL1.04_SIL_numinN,QTL1.15_MPTUtBinN,QTL1.84_MPTUtFinN,QTL2.26_SIL_numinN,QTL4.01_MPTUtBinN,QTL4.01_MPTUtFinN,QTL4.73_LfLinK,QTL5.24_MPTUtBinN,QTL5.25_BranchinN,QTL5.25_MPTUtFinN,QTL5.26_SIL_numinN,QTL5.32_LfLinN,QTL5.92_BranchinN,QTL2.02_MPTUtBinV,QTL2.18_MPTUtFinV,QTL3.39_LfLinV,QTL5.06_LfLinV,QTL5.06_MPTUtBinV,QTL5.90_LfLinV,QTL5.90_MPTUtFinV,QTL5.95_MPTUtBinV)
cov.sem<-cov(Data)
cor(cbind(MPTUtB,MPTUtF,LfL,Branch,SIL_num))

#esting and plotting non-linear effects
Test=lm(SIL_num~MPTUtB+I(MPTUtB^2)+LfL+I(LfL^2)+MPTUtB*LfL)
summary(Test)

B=seq(min(MPTUtB),max(MPTUtB))
L=seq(min(LfL),max(LfL))
S1=summary(Test)$coefficient[1,1]+summary(Test)$coefficient[2,1]*B+summary(Test)$coefficient[3,1]*B^2
S2=summary(Test)$coefficient[1,1]+summary(Test)$coefficient[4,1]*L+summary(Test)$coefficient[5,1]*L^2

par(mfrow=c(1,2))
plot(SIL_num~MPTUtB)
lines(B,S1)
plot(SIL_num~LfL)
lines(L,S2)

